from bluer_objects import README
from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.consts import assets2
from bluer_sbc.README.design import design_doc

image_template = assets2 + "bryce/{}?raw=true"

marquee = README.Items(
    [
        {
            "name": "bryce",
            "marquee": image_template.format("08.jpg"),
            "url": "./bluer_sbc/docs/bryce.md",
        }
    ]
)

items = ImageItems(
    {image_template.format(f"{index+1:02}.jpg"): "" for index in range(9)}
)

docs = [
    design_doc(
        "bryce",
        items,
    )
]



from bluer_objects import README
from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.consts import assets2
from bluer_sbc.README.design import design_doc


image_template = assets2 + "swallow/design/v5/{}?raw=true"

marquee = README.Items(
    [
        {
            "name": "swallow",
            "marquee": image_template.format("01.jpg"),
            "url": "./bluer_sbc/docs/swallow.md",
        }
    ]
)

items = ImageItems(
    {image_template.format(f"{index+1:02}.jpg"): "" for index in range(6)}
)

parts = {
    "BTS7960": "2 x",
    "connector": "2 females",
    "white-terminal": "8 x",
    "nuts-bolts-spacers": "M3: ({})".format(
        " + ".join(
            [
                "8 x 25 mm spacer",
                "4 x 30 mm spacer",
                "4 x nut",
            ]
        )
    ),
    "solid-cable-1-15": "20 cm x (red + black/blue)",
}

docs = [
    design_doc(
        "swallow",
        items,
        parts,
    )
]



from bluer_sbc.README.designs import (
    cheshmak,
    battery_bus,
    adapter_bus,
    swallow,
    swallow_head,
    bryce,
    nafha,
    shelter,
    template,
    ultrasonic_sensor_tester,
)


docs = (
    battery_bus.docs
    + adapter_bus.docs
    + bryce.docs
    + cheshmak.docs
    + nafha.docs
    + shelter.docs
    + swallow_head.docs
    + swallow.docs
    + ultrasonic_sensor_tester.docs
    + template.docs
)



from typing import Dict, List

from bluer_objects import markdown

from bluer_sbc.parts.db import db_of_parts


def design_doc(
    design_name: str,
    items: List[str] = [],
    dict_of_parts: dict = {},
    macros: dict = {},
    own_folder: bool = False,
    parts_reference: str = "./parts",
) -> Dict:
    macros_ = {}
    if dict_of_parts:
        macros_ = {
            "parts_images:::": markdown.generate_table(
                db_of_parts.as_images(
                    dict_of_parts,
                    reference=parts_reference,
                ),
                cols=10,
                log=False,
            ),
            "parts_list:::": db_of_parts.as_list(
                dict_of_parts,
                reference=parts_reference,
                log=False,
            ),
        }

    macros_.update(macros)

    return {
        "path": "../docs/{}{}".format(design_name, "" if own_folder else ".md"),
        "items": items,
        "macros": macros_,
    }
